#include <bits/stdc++.h>
using namespace std;

constexpr int kInf = 1000 * 1000 * 1000 + 7;

struct Fenwick {
    int n;
    vector<long long> fenwick;

    Fenwick(int n): n(n), fenwick(n + 1) {}

    void Add(int position, long long value) {
        for (int i = position + 1; i <= n; i += i & -i) {
            fenwick[i] += value;
        }
    }

    long long Sum(int position) {
        long long r = 0;
        for (int i = position + 1; i > 0; i -= i & -i) {
            r += fenwick[i];
        }

        return r;
    }
};

struct Event {
    int l, r;
    long long value;
    int id;
};

void Solve() {
    int n, q;
    cin >> n >> q;

    vector<int> a(n), cmp;
    for (int& e: a) {
        cin >> e;
        cmp.push_back(e);
    }

    sort(cmp.begin(), cmp.end());
    cmp.erase(unique(cmp.begin(), cmp.end()), cmp.end());

    for (int& e: a) {
        e = lower_bound(cmp.begin(), cmp.end(), e) - cmp.begin();
    }

    vector<int> max_stack, min_stack;
    vector<Event> events;
    for (int i = 0; i < n; ++i) {
        while (!max_stack.empty() && a[max_stack.back()] <= a[i]) 
            max_stack.pop_back();
        while (!min_stack.empty() && a[min_stack.back()] >= a[i])
            min_stack.pop_back();
        max_stack.push_back(i);
        min_stack.push_back(i);
        
        vector<int> indices;
        merge(min_stack.begin(), min_stack.end(), max_stack.begin(), max_stack.end(), back_inserter(indices));
        indices.erase(unique(indices.begin(), indices.end()), indices.end());

        reverse(indices.begin(), indices.end());
        int min_value = kInf;
        int max_value = -kInf;
        int size = static_cast<int>(indices.size());
        for (int i = 0; i < size; ++i) {
            int index = indices[i];
            min_value = min(min_value, a[index]);
            max_value = max(max_value, a[index]);
            int next_index = i + 1 < size ? indices[i + 1] : -1;
            long long value = index - next_index;
            events.push_back({min_value, max_value, value});
        }
    }

    vector<long long> results(q);
    for (int i = 0; i < q; ++i) {
        int l, r;
        cin >> l >> r;
        l = lower_bound(cmp.begin(), cmp.end(), l) - cmp.begin();
        r = upper_bound(cmp.begin(), cmp.end(), r) - cmp.begin() - 1;
        if (l > r)
            continue;
        events.push_back({l, r, -1, i});
    }

    sort(events.begin(), events.end(), [&](const Event& a, const Event& b) {
        if (a.l != b.l) return a.l > b.l;
        return a.value > b.value;
    });

    Fenwick fenwick(cmp.size());
    for (const auto& event: events) {
        if (event.value < 0) {
            results[event.id] = fenwick.Sum(event.r);
            continue;
        }

        fenwick.Add(event.r, event.value);
    }

    for (auto result: results) {
        cout << result << '\n';
    }
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int t;
    cin >> t;
    for (int i = 0; i < t; ++i) {
        Solve();
    }
}